# Datasets

Daft provides simple, performant, and responsible ways to access useful datasets like [Common Crawl](https://commoncrawl.org/get-started).

## Common Crawl

Check out our [Common Crawl dataset guide](../datasets/common-crawl.md) for more examples!

::: daft.datasets.common_crawl.common_crawl
    options:
        filters: ["!^_"]
        heading_level: 3
